==> vtigercrm-5.0.4.tgz: vtigercrm/modules/Contacts/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Contacts/language/en_us.lang.php,v 1.14 2005/03/24 17:47:43 rank Exp $
 * Description:  Defines the English language pack
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = Array(
// Mike Crowe Mod --------------------------------------------------------Added for general search
'LBL_MODULE_NAME'=>'Contacts',
'LBL_INVITEE'=>'Direct Reports',
'LBL_MODULE_TITLE'=>'Contacts: Home',
'LBL_SEARCH_FORM_TITLE'=>'Contact Search',
'LBL_LIST_FORM_TITLE'=>'Contact List',
'LBL_NEW_FORM_TITLE'=>'New Contact',
'LBL_CONTACT_OPP_FORM_TITLE'=>'Contact-Opportunity:',
'LBL_CONTACT'=>'Contact:',

'LBL_LIST_NAME'=>'Name',
'LBL_LIST_LAST_NAME'=>'Last Name',
'LBL_LIST_FIRST_NAME'=>'First Name',
'LBL_LIST_CONTACT_NAME'=>'Contact Name',
'LBL_LIST_TITLE'=>'Title',
'LBL_LIST_ACCOUNT_NAME'=>'Account Name',
'LBL_LIST_EMAIL_ADDRESS'=>'Email',
'LBL_LIST_PHONE'=>'Phone',
'LBL_LIST_CONTACT_ROLE'=>'Role',

//DON'T CONVERT THESE THEY ARE MAPPINGS
'db_last_name' => 'LBL_LIST_LAST_NAME',
'db_first_name' => 'LBL_LIST_FIRST_NAME',
'db_title' => 'LBL_LIST_TITLE',
'db_email1' => 'LBL_LIST_EMAIL_ADDRESS',
'db_email2' => 'LBL_LIST_EMAIL_ADDRESS',
//END DON'T CONVERT
	
'LBL_EXISTING_CONTACT' => 'Used an existing contact',
'LBL_CREATED_CONTACT' => 'Created a new contact',
'LBL_EXISTING_ACCOUNT' => 'Used an existing vtiger_account',
'LBL_CREATED_ACCOUNT' => 'Created a new vtiger_account',
'LBL_CREATED_CALL' => 'Created a new call',
'LBL_CREATED_MEETING' => 'Created a new meeting',
'LBL_ADDMORE_BUSINESSCARD' =>'Add another business card',

'LBL_BUSINESSCARD' => 'Business Card',

'LBL_NAME'=>'Name:',
'LBL_CONTACT_NAME'=>'Contact Name:',
'LBL_CONTACT_INFORMATION'=>'Contact Information',
'LBL_CUSTOM_INFORMATION'=>'Custom Information',
'LBL_FIRST_NAME'=>'First Name:',
'LBL_OFFICE_PHONE'=>'Office Phone:',
'LBL_ACCOUNT_NAME'=>'Account Name:',
'LBL_ANY_PHONE'=>'Any Phone:',
'LBL_PHONE'=>'Phone:',
'LBL_LAST_NAME'=>'Last Name:',
'LBL_MOBILE_PHONE'=>'Mobile:',
'LBL_HOME_PHONE'=>'Home:',
'LBL_LEAD_SOURCE'=>'Lead Source:',
'LBL_OTHER_PHONE'=>'Other Phone:',
'LBL_FAX_PHONE'=>'Fax:',
'LBL_TITLE'=>'Title:',
'LBL_DEPARTMENT'=>'Department:',
'LBL_BIRTHDATE'=>'Birthdate:',
'LBL_EMAIL_ADDRESS'=>'Email:',
'LBL_OTHER_EMAIL_ADDRESS'=>'Other Email:',
'LBL_ANY_EMAIL'=>'Any Email:',
'LBL_REPORTS_TO'=>'Reports To:',
'LBL_ASSISTANT'=>'Assistant:',
'LBL_YAHOO_ID'=>'Yahoo! ID:',
'LBL_ASSISTANT_PHONE'=>'Assistant Phone:',
'LBL_DO_NOT_CALL'=>'Do Not Call:',
'LBL_EMAIL_OPT_OUT'=>'Email Opt Out:',
'LBL_PRIMARY_ADDRESS'=>'Primary Address:',
'LBL_ALTERNATE_ADDRESS'=>'Other Address:',
'LBL_ANY_ADDRESS'=>'Any Address:',
'LBL_CITY'=>'City:',
'LBL_STATE'=>'State:',
'LBL_POSTAL_CODE'=>'Postal Code:',
'LBL_COUNTRY'=>'Country:',
'LBL_DESCRIPTION_INFORMATION'=>'Description Information',
'LBL_IMAGE_INFORMATION'=>'Contact Image Information:',
'LBL_ADDRESS_INFORMATION'=>'Address Information',
'LBL_DESCRIPTION'=>'Description:',
'LBL_CONTACT_ROLE'=>'Role:',
'LBL_OPP_NAME'=>'Opportunity Name:',
'LBL_DUPLICATE'=>'Potential Duplicate Contacts',
'MSG_DUPLICATE' => 'Creating this contact may vtiger_potentialy create a duplicate contact. You may either select a contact from the list below or you may click on Create New Contact to continue creating a new contact with the previously entered data.',

'LNK_NEW_APPOINTMENT' => 'New Appointment',
'LBL_ADD_BUSINESSCARD' => 'Add Business Card',
'NTC_DELETE_CONFIRMATION'=>'Are you sure you want to delete this record?',
'NTC_REMOVE_CONFIRMATION'=>'Are you sure you want to remove this contact from this case?',
'NTC_REMOVE_DIRECT_REPORT_CONFIRMATION'=>'Are you sure you want to remove this record as a direct vtiger_report?',
'ERR_DELETE_RECORD'=>"en_us A record number must be specified to delete the contact.",
'NTC_COPY_PRIMARY_ADDRESS'=>'Copy primary address to alternate address',
'NTC_COPY_ALTERNATE_ADDRESS'=>'Copy alternate address to primary address',

'LBL_SELECT_CONTACT'=>'Select Contact',
//Added for search heading
'LBL_GENERAL_INFORMATION'=>'General Information',



//for v4 release added
'LBL_NEW_POTENTIAL'=>'New Potential',
'LBL_POTENTIAL_TITLE'=>'Potentials',

'LBL_NEW_TASK'=>'New Task',
'LBL_TASK_TITLE'=>'Tasks',
'LBL_NEW_CALL'=>'New Call',
'LBL_CALL_TITLE'=>'Calls',
'LBL_NEW_MEETING'=>'New Meeting',
'LBL_MEETING_TITLE'=>'Meetings',
'LBL_NEW_EMAIL'=>'New Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_NOTE'=>'New Note',
'LBL_NOTE_TITLE'=>'Notes',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Contact Tools',

'Salutation'=>'Salutation',
'First Name'=>'First Name',
'Office Phone'=>'Office Phone',
'Last Name'=>'Last Name',
'Mobile'=>'Mobile',
'Account Name'=>'Account Name',
'Home Phone'=>'Home Phone',
'Lead Source'=>'Lead Source',
'Other Phone'=>'Other Phone',
'Title'=>'Title',
'Fax'=>'Fax',
'Department'=>'Department',
'Birthdate'=>'Birthdate',
'Email'=>'Email',
'Reports To'=>'Reports To',
'Assistant'=>'Assistant',
'Yahoo Id'=>'Yahoo Id',
'Assistant Phone'=>'Assistant Phone',
'Do Not Call'=>'Do Not Call',
'Email Opt Out'=>'Email Opt Out',
'Assigned To'=>'Assigned To',
'Campaign Source'=>'Campaign Source',
'Reference' =>'Reference',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
'Mailing Street'=>'Mailing Street',
'Other Street'=>'Other Street',
'Mailing City'=>'Mailing City',
'Mailing State'=>'Mailing State',
'Mailing Zip'=>'Mailing Postal Code',
'Mailing Country'=>'Mailing Country',
'Mailing Po Box'=>'Mailing PO Box',
'Other Po Box'=>'Other PO Box',
'Other City'=>'Other City',
'Other State'=>'Other State',
'Other Zip'=>'Other Postal Code',
'Other Country'=>'Other Country',
'Contact Image'=>'Contact Image',
'Description'=>'Description',

// Added vtiger_fields for Add Business Card
'LBL_NEW_CONTACT'=>'New Contact',
'LBL_NEW_ACCOUNT'=>'New Account',
'LBL_NOTE_SUBJECT'=>'Note Subject:',
'LBL_NOTE'=>'Note:',
'LBL_WEBSITE'=>'Website:',
'LBL_NEW_APPOINTMENT'=>'New Appointment',
'LBL_SUBJECT'=>'Subject:',
'LBL_START_DATE'=>'Start Date:',
'LBL_START_TIME'=>'Start Time:',

//Added vtiger_field after 4_0_1
'Portal User'=>'Portal User',
'LBL_CUSTOMER_PORTAL_INFORMATION'=>'Customer Portal Information',
'Support Start Date'=>'Support Start Date',
'Support End Date'=>'Support End Date',
//Added for 4.2 Release -- CustomView
'Name'=>'Name',
'LBL_ALL'=>'All',
'LBL_MAXIMUM_LIMIT_ERROR'=>'Sorry, the uploaded file exceeds the maximum vtiger_filesize limit. Please try a file smaller than 800000 bytes',
'LBL_UPLOAD_ERROR'=>'Problems in file upload. Please try again!',
'LBL_IMAGE_ERROR'=>'The given file is not of type image(.gif/.jpg/.png)',
'LBL_INVALID_IMAGE'=>'Invalid file OR File has no data',

//Added after 5Alpha5
'Notify Owner'=>'Notify Owner',

//Added for Picklist Values
'--None--'=>'--None--',

'Mr.'=>'Mr.',
'Ms.'=>'Ms.',
'Mrs.'=>'Mrs.',
'Dr.'=>'Dr.',
'Prof.'=>'Prof.',

'Cold Call'=>'Cold Call',
'Existing Customer'=>'Existing Customer',
'Self Generated'=>'Self Generated',
'Employee'=>'Employee',
'Partner'=>'Partner',
'Public Relations'=>'Public Relations',
'Direct Mail'=>'Direct Mail',
'Conference'=>'Conference',
'Trade Show'=>'Trade Show',
'Web Site'=>'Web Site',
'Word of mouth'=>'Word of mouth',
'Other'=>'Other',
'User List'=>'User List',

//Added for 5.0.3
'Customer Portal Login Details'=>'Customer Portal Login Details',
'Dear'=>'Dear',
'Your Customer Portal Login details are given below:'=>'Your Customer Portal Login details are given below:',
'User Id :'=>'User Id :',
'Password :'=>'Password :',
'Please Login Here'=>'Please Login Here',
'Note :'=>'Note :',
'We suggest you to change your password after logging in first time'=>'We suggest you to change your password after logging in first time.',
'Support Team'=>'Support Team',


'TITLE_AJAX_CSS_POPUP_CHAT'=>'Ajax Css-Popup chat',
);

?>

==> vtigercrm-5.3.0p0.tgz: vtigercrm/modules/Contacts/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Contacts/language/en_us.lang.php,v 1.14 2005/03/24 17:47:43 rank Exp $
 * Description:  Defines the English language pack
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): ______________________________________..
 ********************************************************************************/

$mod_strings = Array(
// Mike Crowe Mod --------------------------------------------------------Added for general search
'LBL_MODULE_NAME'=>'Contacts',
'LBL_INVITEE'=>'Direct Reports',
'LBL_MODULE_TITLE'=>'Contacts: Home',
'LBL_SEARCH_FORM_TITLE'=>'Contact Search',
'LBL_LIST_FORM_TITLE'=>'Contact List',
'LBL_NEW_FORM_TITLE'=>'New Contact',
'LBL_CONTACT_OPP_FORM_TITLE'=>'Contact-Opportunity:',
'LBL_CONTACT'=>'Contact:',

'LBL_LIST_NAME'=>'Name',
'LBL_LIST_LAST_NAME'=>'Last Name',
'LBL_LIST_FIRST_NAME'=>'First Name',
'LBL_LIST_CONTACT_NAME'=>'Contact Name',
'LBL_LIST_TITLE'=>'Title',
'LBL_LIST_ACCOUNT_NAME'=>'Account Name',
'LBL_LIST_EMAIL_ADDRESS'=>'Email',
'LBL_LIST_PHONE'=>'Phone',
'LBL_LIST_CONTACT_ROLE'=>'Role',

//DON'T CONVERT THESE THEY ARE MAPPINGS
'db_last_name' => 'LBL_LIST_LAST_NAME',
'db_first_name' => 'LBL_LIST_FIRST_NAME',
'db_title' => 'LBL_LIST_TITLE',
'db_email1' => 'LBL_LIST_EMAIL_ADDRESS',
'db_email2' => 'LBL_LIST_EMAIL_ADDRESS',
//END DON'T CONVERT
	
'LBL_EXISTING_CONTACT' => 'Used an existing contact',
'LBL_CREATED_CONTACT' => 'Created a new contact',
'LBL_EXISTING_ACCOUNT' => 'Used an existing vtiger_account',
'LBL_CREATED_ACCOUNT' => 'Created a new vtiger_account',
'LBL_CREATED_CALL' => 'Created a new call',
'LBL_CREATED_MEETING' => 'Created a new meeting',
'LBL_ADDMORE_BUSINESSCARD' =>'Add another business card',

'LBL_BUSINESSCARD' => 'Business Card',

'LBL_NAME'=>'Name:',
'LBL_CONTACT_NAME'=>'Contact Name:',
'LBL_CONTACT_INFORMATION'=>'Contact Information',
'LBL_CUSTOM_INFORMATION'=>'Custom Information',
'LBL_FIRST_NAME'=>'First Name:',
'LBL_OFFICE_PHONE'=>'Office Phone:',
'LBL_ACCOUNT_NAME'=>'Account Name:',
'LBL_ANY_PHONE'=>'Any Phone:',
'LBL_PHONE'=>'Phone:',
'LBL_LAST_NAME'=>'Last Name:',
'LBL_MOBILE_PHONE'=>'Mobile:',
'LBL_HOME_PHONE'=>'Home:',
'LBL_LEAD_SOURCE'=>'Lead Source:',
'LBL_OTHER_PHONE'=>'Other Phone:',
'LBL_FAX_PHONE'=>'Fax:',
'LBL_TITLE'=>'Title:',
'LBL_DEPARTMENT'=>'Department:',
'LBL_BIRTHDATE'=>'Birthdate:',
'LBL_EMAIL_ADDRESS'=>'Email:',
'LBL_OTHER_EMAIL_ADDRESS'=>'Other Email:',
'LBL_ANY_EMAIL'=>'Any Email:',
'LBL_REPORTS_TO'=>'Reports To:',
'LBL_ASSISTANT'=>'Assistant:',
'LBL_YAHOO_ID'=>'Yahoo! ID:',
'LBL_ASSISTANT_PHONE'=>'Assistant Phone:',
'LBL_DO_NOT_CALL'=>'Do Not Call:',
'LBL_EMAIL_OPT_OUT'=>'Email Opt Out:',
'LBL_PRIMARY_ADDRESS'=>'Primary Address:',
'LBL_ALTERNATE_ADDRESS'=>'Other Address:',
'LBL_ANY_ADDRESS'=>'Any Address:',
'LBL_CITY'=>'City:',
'LBL_STATE'=>'State:',
'LBL_POSTAL_CODE'=>'Postal Code:',
'LBL_COUNTRY'=>'Country:',
'LBL_DESCRIPTION_INFORMATION'=>'Description Information',
'LBL_IMAGE_INFORMATION'=>'Contact Image Information:',
'LBL_ADDRESS_INFORMATION'=>'Address Information',
'LBL_DESCRIPTION'=>'Description:',
'LBL_CONTACT_ROLE'=>'Role:',
'LBL_OPP_NAME'=>'Opportunity Name:',
'LBL_DUPLICATE'=>'Potential Duplicate Contacts',
'MSG_DUPLICATE' => 'Creating this contact may vtiger_potentialy create a duplicate contact. You may either select a contact from the list below or you may click on Create New Contact to continue creating a new contact with the previously entered data.',

'LNK_NEW_APPOINTMENT' => 'New Appointment',
'LBL_ADD_BUSINESSCARD' => 'Add Business Card',
'NTC_DELETE_CONFIRMATION'=>'Are you sure you want to delete this record?',
'NTC_REMOVE_CONFIRMATION'=>'Are you sure you want to remove this contact from this case?',
'NTC_REMOVE_DIRECT_REPORT_CONFIRMATION'=>'Are you sure you want to remove this record as a direct vtiger_report?',
'ERR_DELETE_RECORD'=>"en_us A record number must be specified to delete the contact.",
'NTC_COPY_PRIMARY_ADDRESS'=>'Copy primary address to alternate address',
'NTC_COPY_ALTERNATE_ADDRESS'=>'Copy alternate address to primary address',

'LBL_SELECT_CONTACT'=>'Select Contact',
//Added for search heading
'LBL_GENERAL_INFORMATION'=>'General Information',



//for v4 release added
'LBL_NEW_POTENTIAL'=>'New Potential',
'LBL_POTENTIAL_TITLE'=>'Potentials',

'LBL_NEW_TASK'=>'New Task',
'LBL_TASK_TITLE'=>'Tasks',
'LBL_NEW_CALL'=>'New Call',
'LBL_CALL_TITLE'=>'Calls',
'LBL_NEW_MEETING'=>'New Meeting',
'LBL_MEETING_TITLE'=>'Meetings',
'LBL_NEW_EMAIL'=>'New Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_NOTE'=>'New Document',
'LBL_NOTE_TITLE'=>'Documents',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Contact Tools',

'Salutation'=>'Salutation',
'First Name'=>'First Name',
'Office Phone'=>'Office Phone',
'Last Name'=>'Last Name',
'Mobile'=>'Mobile',
'Account Name'=>'Account Name',
'Home Phone'=>'Home Phone',
'Lead Source'=>'Lead Source',
'Other Phone'=>'Other Phone',
'Title'=>'Title',
'Fax'=>'Fax',
'Department'=>'Department',
'Birthdate'=>'Birthdate',
'Email'=>'Email',
'Reports To'=>'Reports To',
'Assistant'=>'Assistant',
'Yahoo Id'=>'Yahoo Id',
'Assistant Phone'=>'Assistant Phone',
'Do Not Call'=>'Do Not Call',
'Email Opt Out'=>'Email Opt Out',
'Assigned To'=>'Assigned To',
'Campaign Source'=>'Campaign Source',
'Reference' =>'Reference',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
'Mailing Street'=>'Mailing Street',
'Other Street'=>'Other Street',
'Mailing City'=>'Mailing City',
'Mailing State'=>'Mailing State',
'Mailing Zip'=>'Mailing Postal Code',
'Mailing Country'=>'Mailing Country',
'Mailing Po Box'=>'Mailing PO Box',
'Other Po Box'=>'Other PO Box',
'Other City'=>'Other City',
'Other State'=>'Other State',
'Other Zip'=>'Other Postal Code',
'Other Country'=>'Other Country',
'Contact Image'=>'Contact Image',
'Description'=>'Description',

// Added vtiger_fields for Add Business Card
'LBL_NEW_CONTACT'=>'New Contact',
'LBL_NEW_ACCOUNT'=>'New Account',
'LBL_NOTE_SUBJECT'=>'Document Subject:',
'LBL_NOTE'=>'Note:',
'LBL_WEBSITE'=>'Website:',
'LBL_NEW_APPOINTMENT'=>'New Appointment',
'LBL_SUBJECT'=>'Subject:',
'LBL_START_DATE'=>'Start Date:',
'LBL_START_TIME'=>'Start Time:',

//Added vtiger_field after 4_0_1
'Portal User'=>'Portal User',
'LBL_CUSTOMER_PORTAL_INFORMATION'=>'Customer Portal Information',
'Support Start Date'=>'Support Start Date',
'Support End Date'=>'Support End Date',
//Added for 4.2 Release -- CustomView
'Name'=>'Name',
'LBL_ALL'=>'All',
'LBL_MAXIMUM_LIMIT_ERROR'=>'Sorry, the uploaded file exceeds the maximum vtiger_filesize limit. Please try a file smaller than 800000 bytes',
'LBL_UPLOAD_ERROR'=>'Problems in file upload. Please try again!',
'LBL_IMAGE_ERROR'=>'The given file is not of type image(.gif/.jpg/.png)',
'LBL_INVALID_IMAGE'=>'Invalid file OR File has no data',

//Added after 5Alpha5
'Notify Owner'=>'Notify Owner',

//Added for Picklist Values
'--None--'=>'--None--',

'Mr.'=>'Mr.',
'Ms.'=>'Ms.',
'Mrs.'=>'Mrs.',
'Dr.'=>'Dr.',
'Prof.'=>'Prof.',

'Cold Call'=>'Cold Call',
'Existing Customer'=>'Existing Customer',
'Self Generated'=>'Self Generated',
'Employee'=>'Employee',
'Partner'=>'Partner',
'Public Relations'=>'Public Relations',
'Direct Mail'=>'Direct Mail',
'Conference'=>'Conference',
'Trade Show'=>'Trade Show',
'Web Site'=>'Web Site',
'Word of mouth'=>'Word of mouth',
'Other'=>'Other',
'User List'=>'User List',

//Added for 5.0.3
'Customer Portal Login Details'=>'Customer Portal Login Details',
'Dear'=>'Dear',
'Your Customer Portal Login details are given below:'=>'Your Customer Portal Login details are given below:',
'User Id :'=>'User Id :',
'Password :'=>'Password :',
'Please Login Here'=>'Please Login Here',
'Note :'=>'Note :',
'We suggest you to change your password after logging in first time'=>'We suggest you to change your password after logging in first time.',
'Support Team'=>'Support Team',

'TITLE_AJAX_CSS_POPUP_CHAT'=>'Ajax Css-Popup chat',

// Added after 5.0.4 GA

// Module Sequence Numbering
'Contact Id' => 'Contact Id',
// END

);

?>
